module.exports = defineTest({
	description: 'respects access side-effects when calling a getter'
});
